// AUTOGENERATED FILE - DO NOT EDIT

var pt = window.PropTypes;
var pk = window['dashkit_shadcn'];

pk.AreaChart.propTypes = {id:pt.oneOfType([pt.string]),
 className:pt.oneOfType([pt.string]),
 config:pt.oneOfType([pt.object]),
 data:pt.oneOfType([pt.arrayOf(pt.object)]),
 dataKey:pt.oneOfType([pt.string]),
 xAxisKey:pt.oneOfType([pt.string]),
 yAxisKey:pt.oneOfType([pt.string]),
 showXAxis:pt.any,
 showYAxis:pt.any,
 showGrid:pt.any,
 showTooltip:pt.any,
 showLegend:pt.any,
 stackId:pt.oneOfType([pt.string]),
 fillOpacity:pt.oneOfType([pt.number]),
 strokeWidth:pt.oneOfType([pt.number]),
 curve:pt.oneOfType([pt.string]),
 style:pt.any,
 children:pt.node,
 setProps:pt.oneOfType([pt.any])};
pk.BarChart.propTypes = {id:pt.oneOfType([pt.string]),
 className:pt.oneOfType([pt.string]),
 config:pt.oneOfType([pt.object]),
 data:pt.oneOfType([pt.arrayOf(pt.object)]),
 dataKey:pt.oneOfType([pt.string]),
 xAxisKey:pt.oneOfType([pt.string]),
 yAxisKey:pt.oneOfType([pt.string]),
 showXAxis:pt.any,
 showYAxis:pt.any,
 showGrid:pt.any,
 showTooltip:pt.any,
 showLegend:pt.any,
 stackId:pt.oneOfType([pt.string]),
 radius:pt.oneOfType([pt.number]),
 maxBarSize:pt.oneOfType([pt.number]),
 style:pt.any,
 children:pt.node,
 setProps:pt.oneOfType([pt.any])};
pk.ChartContainer.propTypes = {id:pt.oneOfType([pt.string]),
 className:pt.oneOfType([pt.string]),
 config:pt.objectOf(pt.shape({label:pt.node,icon:pt.any,color:pt.oneOfType([pt.string]),theme:pt.oneOfType([pt.shape({light:pt.string,dark:pt.string})])})),
 children:pt.shape({type:pt.oneOfType([pt.string,pt.any,pt.any]),props:pt.any,key:pt.oneOfType([pt.string])}),
 ref:pt.oneOfType([pt.string,pt.any]),
 key:pt.oneOfType([pt.string,pt.number])};
pk.ChartLegend.propTypes = {ref:pt.oneOfType([pt.string,pt.any]),
 key:pt.oneOfType([pt.string,pt.number])};
pk.ChartTooltip.propTypes = {ref:pt.oneOfType([pt.string,pt.any]),
 key:pt.oneOfType([pt.string,pt.number])};
